@@ -24,4 +24,6 @@
 #
 ###############################################################################
 
-__version__ = u'17.10.1'
+__version__ = '22.7.1'
+
+__build__ = '00000000-0000000'
