@@ -44,12 +44,12 @@ class Component(ApplicationSession):
         def on_heartbeat(details=None):
             print("Got heartbeat (publication ID {})".format(details.publication))
 
-        await self.subscribe(on_heartbeat, u'com.myapp.heartbeat', options=SubscribeOptions(details_arg='details'))
+        await self.subscribe(on_heartbeat, 'com.myapp.heartbeat', options=SubscribeOptions(details_arg='details'))
 
         def on_topic2(a, b, c=None, d=None):
             print("Got event: {} {} {} {}".format(a, b, c, d))
 
-        await self.subscribe(on_topic2, u'com.myapp.topic2')
+        await self.subscribe(on_topic2, 'com.myapp.topic2')
         asyncio.get_event_loop().call_later(5, self.leave)
 
     def onDisconnect(self):
@@ -57,8 +57,7 @@ class Component(ApplicationSession):
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
