@@ -24,8 +24,6 @@
 #
 ###############################################################################
 
-from __future__ import print_function
-
 import asyncio
 from os import environ
 from autobahn.asyncio.wamp import ApplicationSession, ApplicationRunner
@@ -41,7 +39,7 @@ class Component(ApplicationSession):
         counter = 0
         while True:
             print("publish: com.myapp.topic1", counter)
-            self.publish(u'com.myapp.topic1', counter)
+            self.publish('com.myapp.topic1', counter)
             counter += 1
             await asyncio.sleep(1)
 
@@ -54,8 +52,8 @@ if __name__ == '__main__':
     options = ssl.create_default_context(cadata=open(cert_path, 'r').read())
     # ...which we pass as "ssl=" to ApplicationRunner (passed to loop.create_connection)
     runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"wss://127.0.0.1:8083/ws"),
-        u"crossbardemo",
+        environ.get("AUTOBAHN_DEMO_ROUTER", "wss://127.0.0.1:8083/ws"),
+        "crossbardemo",
         ssl=options,  # try removing this, but still use self-signed cert
     )
     runner.run(Component)
