@@ -36,40 +36,40 @@ class Component(ApplicationSession):
 
     async def onJoin(self, details):
 
-        await self.call(u'com.arguments.ping')
+        await self.call('com.arguments.ping')
         print("Pinged!")
 
-        res = await self.call(u'com.arguments.add2', 2, 3)
+        res = await self.call('com.arguments.add2', 2, 3)
         print("Add2: {}".format(res))
 
-        starred = await self.call(u'com.arguments.stars')
+        starred = await self.call('com.arguments.stars')
         print("Starred 1: {}".format(starred))
 
-        starred = await self.call(u'com.arguments.stars', nick=u'Homer')
+        starred = await self.call('com.arguments.stars', nick='Homer')
         print("Starred 2: {}".format(starred))
 
-        starred = await self.call(u'com.arguments.stars', stars=5)
+        starred = await self.call('com.arguments.stars', stars=5)
         print("Starred 3: {}".format(starred))
 
-        starred = await self.call(u'com.arguments.stars', nick=u'Homer', stars=5)
+        starred = await self.call('com.arguments.stars', nick='Homer', stars=5)
         print("Starred 4: {}".format(starred))
 
-        orders = await self.call(u'com.arguments.orders', u'coffee')
+        orders = await self.call('com.arguments.orders', 'coffee')
         print("Orders 1: {}".format(orders))
 
-        orders = await self.call(u'com.arguments.orders', u'coffee', limit=10)
+        orders = await self.call('com.arguments.orders', 'coffee', limit=10)
         print("Orders 2: {}".format(orders))
 
-        arglengths = await self.call(u'com.arguments.arglen')
+        arglengths = await self.call('com.arguments.arglen')
         print("Arglen 1: {}".format(arglengths))
 
-        arglengths = await self.call(u'com.arguments.arglen', 1, 2, 3)
+        arglengths = await self.call('com.arguments.arglen', 1, 2, 3)
         print("Arglen 1: {}".format(arglengths))
 
-        arglengths = await self.call(u'com.arguments.arglen', a=1, b=2, c=3)
+        arglengths = await self.call('com.arguments.arglen', a=1, b=2, c=3)
         print("Arglen 2: {}".format(arglengths))
 
-        arglengths = await self.call(u'com.arguments.arglen', 1, 2, 3, a=1, b=2, c=3)
+        arglengths = await self.call('com.arguments.arglen', 1, 2, 3, a=1, b=2, c=3)
         print("Arglen 3: {}".format(arglengths))
 
         self.leave()
@@ -79,8 +79,7 @@ class Component(ApplicationSession):
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
