@@ -40,7 +40,7 @@ class Component(ApplicationSession):
         def on_progress(i):
             print("Progress: {}".format(i))
 
-        res = await self.call(u'com.myapp.longop', 3, options=CallOptions(on_progress=on_progress))
+        res = await self.call('com.myapp.longop', 3, options=CallOptions(on_progress=on_progress))
 
         print("Final: {}".format(res))
 
@@ -51,8 +51,7 @@ class Component(ApplicationSession):
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
