@@ -50,14 +50,14 @@ class Component(ApplicationSession):
             print("heartbeat (publication ID {})".format(details.publication))
 
         yield self.subscribe(
-            on_heartbeat, u'com.myapp.heartbeat',
+            on_heartbeat, 'com.myapp.heartbeat',
             options=SubscribeOptions(details_arg='details')
         )
 
         def on_topic2(a, b, c=None, d=None):
             print("Got event: {} {} {} {}".format(a, b, c, d))
 
-        yield self.subscribe(on_topic2, u'com.myapp.topic2')
+        yield self.subscribe(on_topic2, 'com.myapp.topic2')
 
         reactor.callLater(5, self.leave)
 
@@ -67,8 +67,7 @@ class Component(ApplicationSession):
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
