@@ -24,8 +24,6 @@
 #
 ###############################################################################
 
-from __future__ import print_function
-
 from os import environ
 from twisted.internet.defer import inlineCallbacks
 
@@ -46,7 +44,7 @@ class Component(ApplicationSession):
         def on_event(i):
             print("Got event: {}".format(i))
 
-        yield self.subscribe(on_event, u'com.myapp.topic1')
+        yield self.subscribe(on_event, 'com.myapp.topic1')
 
         counter = 0
         while True:
@@ -56,7 +54,7 @@ class Component(ApplicationSession):
                 exclude_me=False
             )
             publication = yield self.publish(
-                u'com.myapp.topic1', counter,
+                'com.myapp.topic1', counter,
                 options=pub_options,
             )
             print("Published with publication ID {}".format(publication.id))
@@ -65,8 +63,7 @@ class Component(ApplicationSession):
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
