@@ -45,20 +45,19 @@ class Component(ApplicationSession):
         def add_complex(a, ai, b, bi):
             return CallResult(c=a + b, ci=ai + bi)
 
-        yield self.register(add_complex, u'com.myapp.add_complex')
+        yield self.register(add_complex, 'com.myapp.add_complex')
 
         def split_name(fullname):
             forename, surname = fullname.split()
             return CallResult(forename, surname)
 
-        yield self.register(split_name, u'com.myapp.split_name')
+        yield self.register(split_name, 'com.myapp.split_name')
 
         print("procedures registered")
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
