@@ -35,7 +35,7 @@ from autobahn.wamp.exception import ApplicationError
 from autobahn.twisted.wamp import ApplicationSession, ApplicationRunner
 
 
-@wamp.error(u"com.myapp.error1")
+@wamp.error("com.myapp.error1")
 class AppError1(Exception):
     """
     An application specific exception that is decorated with a WAMP URI,
@@ -56,7 +56,7 @@ class Component(ApplicationSession):
         ##
         for x in [2, 0, -2]:
             try:
-                res = yield self.call(u'com.myapp.sqrt', x)
+                res = yield self.call('com.myapp.sqrt', x)
             except Exception as e:
                 print("Error: {} {}".format(e, e.args))
             else:
@@ -66,7 +66,7 @@ class Component(ApplicationSession):
         ##
         for name in ['foo', 'a', '*' * 11, 'Hello']:
             try:
-                res = yield self.call(u'com.myapp.checkname', name)
+                res = yield self.call('com.myapp.checkname', name)
             except ApplicationError as e:
                 print("Error: {} {} {} {}".format(e, e.error, e.args, e.kwargs))
             else:
@@ -77,7 +77,7 @@ class Component(ApplicationSession):
         self.define(AppError1)
 
         try:
-            yield self.call(u'com.myapp.compare', 3, 17)
+            yield self.call('com.myapp.compare', 3, 17)
         except AppError1 as e:
             print("Compare Error: {}".format(e))
 
@@ -90,8 +90,7 @@ class Component(ApplicationSession):
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
