@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Tavendo GmbH
+# Copyright (c) Crossbar.io Technologies GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -62,7 +62,7 @@ if __name__ == "__main__":
     log.startLogging(sys.stdout)
 
     # create a Twisted Web resource for our WebSocket server
-    wsFactory = WebSocketServerFactory(u"ws://127.0.0.1:8080")
+    wsFactory = WebSocketServerFactory("ws://127.0.0.1:8080")
     wsFactory.protocol = EchoServerProtocol
     wsResource = WebSocketResource(wsFactory)
 
@@ -71,7 +71,7 @@ if __name__ == "__main__":
 
     # create a root resource serving everything via WSGI/Flask, but
     # the path "/ws" served by our WebSocket stuff
-    rootResource = WSGIRootResource(wsgiResource, {'ws': wsResource})
+    rootResource = WSGIRootResource(wsgiResource, {b'ws': wsResource})
 
     # create a Twisted Web Site and run everything
     site = Site(rootResource)
