@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Tavendo GmbH
+# Copyright (c) Crossbar.io Technologies GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -51,7 +51,7 @@ if __name__ == '__main__':
 
     wrappedFactory = Factory.forProtocol(HelloClientProtocol)
     factory = WrappingWebSocketClientFactory(wrappedFactory,
-                                             u"ws://127.0.0.1:9000",
+                                             "ws://127.0.0.1:9000",
                                              enableCompression=False,
                                              autoFragmentSize=1024)
 
